@@ -69,6 +69,12 @@ sub element_req {
 
 
 
+=head1 CATALYST METHODS
+
+These methods are injected into the Catalyst class, available to call
+on the $c object.
+
+
 =head2 $c->this_request_except(%new_params)
 
 Return uri which is identical to the current request, except
@@ -90,6 +96,27 @@ sub Catalyst::this_request_except {
 
 
 
+
+
+=head2 $c->uri_for_controller($action, @params)
+
+Return a URI that points to the $action in this controller, no matter
+what the current request is (it could be to an action in another
+Controller which forwarded to this Controller (by first forwarding to
+this controller's C<set_crud_controller>).
+
+The @params are added to the URI the same way as in C<uri_for>.
+
+=cut
+sub Catalyst::uri_for_controller {
+    my ($c, $action, @params) = @_;
+    return( $c->uri_for( $c->stash->{controller_namespace}, $action, @params) );
+}
+
+
+
+
+
 =head1 AUTHOR
 
 Johan Lindstrom <johanl T cpan.org>
